# Managed API for Confluence On-Premise
Managed API for Confluence On-Premise is an API Client for Confluence On-Premise by [Adaptavist](https://www.adaptavist.com/) primarily designed for the use in [ScriptRunner Connect](https://scriptrunnerconnect.com). You can read more about Managed APIs [here](https://docs.adaptavist.com/src/managed-apis).

This is a runtime agnostic version of the Managed API (with `core` suffix) that makes it easy to port it to any runtime you may want to use this Managed API on.

# Platform specific ports
- [ScriptRunner Connect](https://www.npmjs.com/package/@managed-api/confluence-on-prem-v7-sr-connect)

# Supported API calls
- [fetch](https://docs.adaptavist.com/src/managed-apis/managed-api-abstractions)
- Content
    - [createContent](https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/content-createContent)
    - [getContents](https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/content-getContent)
    - [updateContent](https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/content-update)
    - [getContent](https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/content-getContentById)
    - [deleteContent](https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/content-delete)
    - [getContentHistory](https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/content-getHistory)
    - Child
        - [getChildren](https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/content/{id}/child-children)
        - [getChildrenOfType](https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/content/{id}/child-childrenOfType)
        - [getComments](https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/content/{id}/child-commentsOfContent)
    - Attachment
        - [getAttachments](https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/content/{id}/child/attachment-getAttachments)
    - Label
        - [getLabels](https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/content/{id}/label-labels)
        - [addLabels](https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/content/{id}/label-addLabels)
        - [deleteLabel](https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/content/{id}/label-deleteLabel)
    - Watcher
        - [addWatcher](https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/user/watch-addContentWatcher)
        - [removeWatcher](https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/user/watch-removeContentWatcher)
- Space
    - [getSpaces](https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/space-spaces)
    - [createSpace](https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/space-createSpace)
    - [updateSpace](https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/space-update)
    - [deleteSpace](https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/space-delete)
- User
    - [getUser](https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/user-getUser)

# Porting to other runtimes
While the primary reason for creating Managed APIs was to use them in [ScriptRunner Connect](https://scriptrunnerconnect.com) runtime, then you can easily port them to any runtime of your choosing.

You can do so by extending the `*Core` Managed API class where you'll be asked to provide implementation for `getPlatformImplementation` function. In this implementation you have yo specify how to perform buffer encoding/decoding operations and how to perform HTTP calls:
```typescript
{
    buffer: {
        encode(input: string): ArrayBuffer;
        decode(input: ArrayBuffer): string;
    },
    performHttpCall(request: Request): Promise<Response>
}
```

Here is an example how to create a [Node](https://nodejs.org/en/) port of the Managed API:
```typescript
import { ConfluenceOnPremApiCore } from "@managed-api/confluence-on-prem-v7-core";
import { PlatformImplementation, Request, Response, Headers } from "@managed-api/commons-core";
import fetch from "node-fetch";

export class ConfluenceOnPremApi extends ConfluenceOnPremApiCore {
    constructor(private baseUrl: string, private authToken: string) {
        super();
    }

    protected getPlatformImplementation(): PlatformImplementation {
        return {
            buffer: {
                encode: (input) => Buffer.from(input, 'utf-8'),
                decode: (input) => Buffer.from(input).toString('utf-8')
            },
            performHttpCall: (request) => this.performHttpCall(request)
        };
    }

    private async performHttpCall(request: Request): Promise<Response> {
        const requestUrl = `${this.baseUrl}${request.url}`; // Substitute base URL
        request.headers.set('Authorization', `Basic ${this.authToken}`); // Substitute auth token
        const response = await fetch(requestUrl, {
            method: request.method,
            headers: request.headers as any,
            body: request.method.toLowerCase() !== 'get' ? Buffer.from((await request.arrayBuffer()) ?? new ArrayBuffer(0)) : undefined
        });

        const apiHeaders = new Headers();
        response.headers.forEach((value, key) => apiHeaders.append(key, value));

        const body = await response.arrayBuffer();

        return super.buildResponse(response.url, response.status, response.statusText, apiHeaders, body);
    }
}
```

Please note that the authentication handling details may not be accurate and serve as an example. If you wish yo use these Managed APIs without having to concern yourself how to deal with and secure authentication details when working with APIs, then feel free to evaluate [ScriptRunner Connect](https://scriptrunnerconnect.com) platform.

# Contact
At this time Managed APIs are unlicensed and close sourced, but feel free to drop an email to [eknoll@adaptavist.com](mailto://eknoll@adaptavist.com) for ideas, suggestions and improvements.

# Changelog
- 2.0.0
    - `Breaking change:` URL and query string parameters are now URL encoded, meaning if you encoded them explicitly before you have to remove your own encoding, otherwise they will get double encoded.
- 0.1.2
    - Fixed README

Copyright Adaptavist 2022 (c) All rights reserved