/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { Response, Request, BaseApiCore, constructHeaders, constructUrl, executeHttpCall } from '@managed-api/commons-core';
import { errorMessageBuilder } from './common';
import { customErrorHandlers, errorStrategyBuilderConstructor } from './errorStrategy';
;
export class ConfluenceOnPremApiCore extends BaseApiCore {
    constructor(options) {
        var _a, _b;
        super();
        this.options = options;
        if (!((_a = this.options) === null || _a === void 0 ? void 0 : _a.errorStrategy) && ((_b = this.options) === null || _b === void 0 ? void 0 : _b.errorStrategy) !== null) {
            this.setGlobalErrorStrategy((builder) => builder.retryOnRateLimiting(-1));
        }
        this.Content = new ContentGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Space = new SpaceGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.User = new UserGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.All = new AllGroup(this.Content, this.Space, this.User);
    }
    setGlobalErrorStrategy(errorStrategy) {
        var _a;
        this.options = {
            ...(_a = this.options) !== null && _a !== void 0 ? _a : {},
            errorStrategy
        };
    }
    buildResponse(url, status, statusText, headers, body) {
        const response = new Response(url, status, statusText, headers, body);
        response.setBufferImplementation(this.implementation);
        return response;
    }
    getGlobalErrorStrategy() {
        var _a;
        return (_a = this.options) === null || _a === void 0 ? void 0 : _a.errorStrategy;
    }
}
class AllGroup {
    constructor(Content, Space, User) {
        this.Content = Content;
        this.Space = Space;
        this.User = User;
    }
    /**
     * Creates a new piece of Content or publishes the draft if the content id is present. For the case publishing draft, a new piece of content will be created and all metadata from the draft will be transferred into the newly created content.
     * Alternative usage: Content.createContent
     * Documentation: https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/content-createContent
     * @param options Request options.
     */
    async createContent(options) {
        return this.Content.createContent(options);
    }
    /**
     * Returns a paginated list of Content.
     * Alternative usage: Content.getContents
     * Documentation: https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/content-getContent
     * @param options Request options.
     */
    async getContents(options) {
        return this.Content.getContents(options);
    }
    /**
     * Updates a piece of Content, including changes to content status
     * Alternative usage: Content.updateContent
     * Documentation: https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/content-update
     * @param options Request options.
     */
    async updateContent(options) {
        return this.Content.updateContent(options);
    }
    /**
     * Returns a piece of Content.
     * Alternative usage: Content.getContent
     * Documentation: https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/content-getContentById
     * @param options Request options.
     */
    async getContent(options) {
        return this.Content.getContent(options);
    }
    /**
     * Trashes or purges a piece of Content, based on its {@link ContentType} and {@link ContentStatus}.
     * Alternative usage: Content.deleteContent
     * Documentation: https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/content-delete
     * @param options Request options.
     */
    async deleteContent(options) {
        return this.Content.deleteContent(options);
    }
    /**
     * Returns the history of a particular piece of content
     * Alternative usage: Content.getContentHistory
     * Documentation: https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/content-getHistory
     * @param options Request options.
     */
    async getContentHistory(options) {
        return this.Content.getContentHistory(options);
    }
    /**
     * Returns a map of the direct children of a piece of Content. Content can have multiple types of children - for example a Page can have children that are also Pages, but it can also have Comments and Attachments.
     * Alternative usage: Content.Child.getChildren
     * Documentation: https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/content/{id}/child-children
     * @param options Request options.
     */
    async getContentChildren(options) {
        return this.Content.Child.getChildren(options);
    }
    /**
     * Returns the direct children of a piece of Content, limited to a single child type. The {@link ContentType}(s) of the children returned is specified by the "type" path parameter in the request.
     * Alternative usage: Content.Child.getChildrenOfType
     * Documentation: https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/content/{id}/child-childrenOfType
     * @param options Request options.
     */
    async getContentChildrenOfType(options) {
        return this.Content.Child.getChildrenOfType(options);
    }
    /**
     * Returns the comments of a content
     * Alternative usage: Content.Child.getComments
     * Documentation: https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/content/{id}/child-commentsOfContent
     * @param options Request options.
     */
    async getContentComments(options) {
        return this.Content.Child.getComments(options);
    }
    /**
     * Returns a paginated list of attachment Content entities within a single container.
     * Alternative usage: Content.Attachment.getAttachments
     * Documentation: https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/content/{id}/child/attachment-getAttachments
     * @param options Request options.
     */
    async getContentAttachments(options) {
        return this.Content.Attachment.getAttachments(options);
    }
    /**
     * Returns the list of labels on a piece of Content.
     * Alternative usage: Content.Label.getLabels
     * Documentation: https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/content/{id}/label-labels
     * @param options Request options.
     */
    async getContentLabels(options) {
        return this.Content.Label.getLabels(options);
    }
    /**
     * Adds a list of labels to the specified content. The body is the json representation of the list.
     * Alternative usage: Content.Label.addLabels
     * Documentation: https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/content/{id}/label-addLabels
     * @param options Request options.
     */
    async addContentLabels(options) {
        return this.Content.Label.addLabels(options);
    }
    /**
     * Deletes a labels to the specified content. When calling this method through REST the label parameter doesn't accept "/" characters in label names, because of security constraints. For this case please use the query parameter version of this method (/content/{id}/label?name={label}
     * Alternative usage: Content.Label.deleteLabel
     * Documentation: https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/content/{id}/label-deleteLabel
     * @param options Request options.
     */
    async deleteContentLabel(options) {
        return this.Content.Label.deleteLabel(options);
    }
    /**
     * Create a new watcher for the given user and content id. User is optional. If not specified, currently logged-in user will be used. Otherwise, it can be specified by either user key or username. When a user is specified and is different from the logged-in user, the logged-in user needs to be a Confluence administrator.
     * Alternative usage: Content.Watcher.addWatcher
     * Documentation: https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/user/watch-addContentWatcher
     * @param options Request options.
     */
    async addContentWatcher(options) {
        return this.Content.Watcher.addWatcher(options);
    }
    /**
     * Delete an existing watcher for the given user and content id. User is optional. If not specified, currently logged-in user will be used. Otherwise, it can be specified by either user key or username. When a user is specified and is different from the logged-in user, the logged-in user needs to be a Confluence administrator.
     * Alternative usage: Content.Watcher.removeWatcher
     * Documentation: https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/user/watch-removeContentWatcher
     * @param options Request options.
     */
    async removeContentWatcher(options) {
        return this.Content.Watcher.removeWatcher(options);
    }
    /**
     * Returns information about a number of spaces.
     * Alternative usage: Space.getSpaces
     * Documentation: https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/space-spaces
     * @param options Request options.
     */
    async getSpaces(options) {
        return this.Space.getSpaces(options);
    }
    /**
     * Creates a new Space. The incoming Space does not include an id, but must include a Key and Name, and should include a Description.
     * Alternative usage: Space.createSpace
     * Documentation: https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/space-createSpace
     * @param options Request options.
     */
    async createSpace(options) {
        return this.Space.createSpace(options);
    }
    /**
     * Updates a Space. Currently only the Space name, description and homepage can be updated.
     * Alternative usage: Space.updateSpace
     * Documentation: https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/space-update
     * @param options Request options.
     */
    async updateSpace(options) {
        return this.Space.updateSpace(options);
    }
    /**
     * Deletes a Space. The space is deleted in a long running task, so the space cannot be considered deleted when this resource returns. Clients can follow the status link in the response and poll it until the task completes.
     * Alternative usage: Space.deleteSpace
     * Documentation: https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/space-delete
     * @param options Request options.
     */
    async deleteSpace(options) {
        return this.Space.deleteSpace(options);
    }
    /**
     * Get information about a user identified by either user key or username.
     * Alternative usage: User.getUser
     * Documentation: https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/user-getUser
     * @param options Request options.
     */
    async getUser(options) {
        return this.User.getUser(options);
    }
}
class ContentGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Child = new ContentChildGroup(implementation, this.getGlobalErrorStrategy);
        this.Attachment = new ContentAttachmentGroup(implementation, this.getGlobalErrorStrategy);
        this.Label = new ContentLabelGroup(implementation, this.getGlobalErrorStrategy);
        this.Watcher = new ContentWatcherGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
     * Creates a new piece of Content or publishes the draft if the content id is present. For the case publishing draft, a new piece of content will be created and all metadata from the draft will be transferred into the newly created content.
     * Documentation: https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/content-createContent
     * @param options Request options.
     */
    async createContent(options) {
        const { headers, body, status, expand, errorStrategy } = options;
        const queryParams = { status, expand };
        const request = new Request('POST', constructUrl('/rest/api/content', queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Returns a paginated list of Content.
     * Documentation: https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/content-getContent
     * @param options Request options.
     */
    async getContents(options) {
        const { headers, type, spaceKey, title, status, postingDay, expand, start, limit, errorStrategy } = options !== null && options !== void 0 ? options : {};
        const queryParams = { type, spaceKey, title, status, postingDay, expand, start, limit };
        const request = new Request('GET', constructUrl('/rest/api/content', queryParams), constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Updates a piece of Content, including changes to content status
     * Documentation: https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/content-update
     * @param options Request options.
     */
    async updateContent(options) {
        const { headers, body, contentId, status, conflictPolicy, errorStrategy } = options;
        const queryParams = { status, conflictPolicy };
        const request = new Request('PUT', constructUrl(`/rest/api/content/${encodeURIComponent(contentId)}`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Returns a piece of Content.
     * Documentation: https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/content-getContentById
     * @param options Request options.
     */
    async getContent(options) {
        const { headers, id, status, version, expand, errorStrategy } = options;
        const queryParams = { status, version, expand };
        const request = new Request('GET', constructUrl(`/rest/api/content/${encodeURIComponent(id)}`, queryParams), constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Trashes or purges a piece of Content, based on its {@link ContentType} and {@link ContentStatus}.
     * Documentation: https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/content-delete
     * @param options Request options.
     */
    async deleteContent(options) {
        const { headers, id, status, errorStrategy } = options;
        const queryParams = { status };
        const request = new Request('DELETE', constructUrl(`/rest/api/content/${encodeURIComponent(id)}`, queryParams), constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     * Returns the history of a particular piece of content
     * Documentation: https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/content-getHistory
     * @param options Request options.
     */
    async getContentHistory(options) {
        const { headers, id, expand, errorStrategy } = options;
        const queryParams = { expand };
        const request = new Request('GET', constructUrl(`/rest/api/content/${encodeURIComponent(id)}/history`, queryParams), constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ContentChildGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Returns a map of the direct children of a piece of Content. Content can have multiple types of children - for example a Page can have children that are also Pages, but it can also have Comments and Attachments.
     * Documentation: https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/content/{id}/child-children
     * @param options Request options.
     */
    async getChildren(options) {
        const { headers, id, expand, parentVersion, start, limit, errorStrategy } = options;
        const queryParams = { expand, parentVersion, start, limit };
        const request = new Request('GET', constructUrl(`/rest/api/content/${encodeURIComponent(id)}/child`, queryParams), constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Returns the direct children of a piece of Content, limited to a single child type. The {@link ContentType}(s) of the children returned is specified by the "type" path parameter in the request.
     * Documentation: https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/content/{id}/child-childrenOfType
     * @param options Request options.
     */
    async getChildrenOfType(options) {
        const { headers, id, type, expand, parentVersion, start, limit, errorStrategy } = options;
        const queryParams = { expand, parentVersion, start, limit };
        const request = new Request('GET', constructUrl(`/rest/api/content/${encodeURIComponent(id)}/child/${encodeURIComponent(type)}`, queryParams), constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Returns the comments of a content
     * Documentation: https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/content/{id}/child-commentsOfContent
     * @param options Request options.
     */
    async getComments(options) {
        const { headers, id, expand, parentVersion, start, limit, location, depth, errorStrategy } = options;
        const queryParams = { expand, parentVersion, start, limit, location, depth };
        const request = new Request('GET', constructUrl(`/rest/api/content/${encodeURIComponent(id)}/child/comment`, queryParams), constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ContentAttachmentGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Returns a paginated list of attachment Content entities within a single container.
     * Documentation: https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/content/{id}/child/attachment-getAttachments
     * @param options Request options.
     */
    async getAttachments(options) {
        const { headers, id, expand, start, limit, filename, mediaType, errorStrategy } = options;
        const queryParams = { expand, start, limit, filename, mediaType };
        const request = new Request('GET', constructUrl(`/rest/api/content/${encodeURIComponent(id)}/child/attachment`, queryParams), constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ContentLabelGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Returns the list of labels on a piece of Content.
     * Documentation: https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/content/{id}/label-labels
     * @param options Request options.
     */
    async getLabels(options) {
        const { headers, id, prefix, start, limit, errorStrategy } = options;
        const queryParams = { prefix, start, limit };
        const request = new Request('GET', constructUrl(`/rest/api/content/${encodeURIComponent(id)}/label`, queryParams), constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Adds a list of labels to the specified content. The body is the json representation of the list.
     * Documentation: https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/content/{id}/label-addLabels
     * @param options Request options.
     */
    async addLabels(options) {
        const { headers, body, id, errorStrategy } = options;
        const request = new Request('POST', constructUrl(`/rest/api/content/${encodeURIComponent(id)}/label`), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Deletes a labels to the specified content. When calling this method through REST the label parameter doesn't accept "/" characters in label names, because of security constraints. For this case please use the query parameter version of this method (/content/{id}/label?name={label}
     * Documentation: https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/content/{id}/label-deleteLabel
     * @param options Request options.
     */
    async deleteLabel(options) {
        const { headers, id, label, errorStrategy } = options;
        const request = new Request('DELETE', constructUrl(`/rest/api/content/${encodeURIComponent(id)}/label/${encodeURIComponent(label)}`), constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class ContentWatcherGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Create a new watcher for the given user and content id. User is optional. If not specified, currently logged-in user will be used. Otherwise, it can be specified by either user key or username. When a user is specified and is different from the logged-in user, the logged-in user needs to be a Confluence administrator.
     * Documentation: https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/user/watch-addContentWatcher
     * @param options Request options.
     */
    async addWatcher(options) {
        const { headers, contentId, key, username, errorStrategy } = options;
        const queryParams = { key, username };
        const request = new Request('POST', constructUrl(`/rest/api/user/watch/content/${encodeURIComponent(contentId)}`, queryParams), constructHeaders(null, { 'Content-Type': 'application/json', ...headers }), null);
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Delete an existing watcher for the given user and content id. User is optional. If not specified, currently logged-in user will be used. Otherwise, it can be specified by either user key or username. When a user is specified and is different from the logged-in user, the logged-in user needs to be a Confluence administrator.
     * Documentation: https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/user/watch-removeContentWatcher
     * @param options Request options.
     */
    async removeWatcher(options) {
        const { headers, contentId, key, username, errorStrategy } = options;
        const queryParams = { key, username };
        const request = new Request('DELETE', constructUrl(`/rest/api/user/watch/content/${encodeURIComponent(contentId)}`, queryParams), constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class SpaceGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Returns information about a number of spaces.
     * Documentation: https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/space-spaces
     * @param options Request options.
     */
    async getSpaces(options) {
        const { headers, spaceKey, type, status, label, favourite, expand, start, limit, errorStrategy } = options !== null && options !== void 0 ? options : {};
        const queryParams = { spaceKey, type, status, label, favourite, expand, start, limit };
        const request = new Request('GET', constructUrl('/rest/api/space', queryParams, true), constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Creates a new Space. The incoming Space does not include an id, but must include a Key and Name, and should include a Description.
     * Documentation: https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/space-createSpace
     * @param options Request options.
     */
    async createSpace(options) {
        const { headers, body, errorStrategy } = options;
        const request = new Request('POST', constructUrl('/rest/api/space'), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Updates a Space. Currently only the Space name, description and homepage can be updated.
     * Documentation: https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/space-update
     * @param options Request options.
     */
    async updateSpace(options) {
        const { headers, body, spaceKey, errorStrategy } = options;
        const request = new Request('PUT', constructUrl(`/rest/api/space/${encodeURIComponent(spaceKey)}`), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Deletes a Space. The space is deleted in a long running task, so the space cannot be considered deleted when this resource returns. Clients can follow the status link in the response and poll it until the task completes.
     * Documentation: https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/space-delete
     * @param options Request options.
     */
    async deleteSpace(options) {
        const { headers, spaceKey, errorStrategy } = options;
        const request = new Request('DELETE', constructUrl(`/rest/api/space/${encodeURIComponent(spaceKey)}`), constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class UserGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Get information about a user identified by either user key or username.
     * Documentation: https://docs.atlassian.com/ConfluenceServer/rest/7.11.1/#api/user-getUser
     * @param options Request options.
     */
    async getUser(options) {
        const { headers, key, username, expand, errorStrategy } = options;
        const queryParams = { key, username, expand };
        const request = new Request('GET', constructUrl('/rest/api/user', queryParams), constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
